<h1>Regression</h1>
<div class="photon-docu-header">
    <p>
        In contrast to a <a href="../classification/">classification</a> task, 
        a regression model is based on continuous target values.
    </p>
</div>

<h3>Regression with default pipeline</h3>
``` python
{% include "examples/basic/regression.py" %} 

```

<h3>Regression with custom pipeline</h3>

``` python
{% include "examples/basic/regression_custom.py" %} 

```